Async<T> class
- Implemented types
Constructors
Properties
-
future
→ Future<
T> Function() -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key
-
final
- onError → Widget Function(Object error, StackTrace? stack)
-
final
- onLoading → Widget Function()
-
final
- onSuccess → Widget Function(T value)
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
render(
Rect area, Buffer buffer, RenderContext ctx) → void -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited