AsyncResult<T, E> class
- Implemented types
Constructors
-
AsyncResult({required Key key, required Future<
Result< future(), required Widget onLoading(), required Widget onSuccess(T value), required Widget onFailure(E failure), required Widget onError(Object error, StackTrace? stack)})T, E> > -
const
Properties
-
future
→ Future<
Result< Function()T, E> > -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key
-
final
- onError → Widget Function(Object error, StackTrace? stack)
-
final
- onFailure → Widget Function(E failure)
-
final
- onLoading → Widget Function()
-
final
- onSuccess → Widget Function(T value)
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
render(
Rect area, Buffer buffer, RenderContext ctx) → void -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited