AsyncStream<T> class

Implemented types

Constructors

AsyncStream({required Key key, required Stream<T> stream(), required Widget onLoading(), required Widget onData(T value), required Widget onError(Object error, StackTrace? stack), Widget onDone()?})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
key Key
final
onData Widget Function(T value)
final
onDone Widget Function()?
final
onError Widget Function(Object error, StackTrace? stack)
final
onLoading Widget Function()
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stream Stream<T> Function()
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
render(Rect area, Buffer buffer, RenderContext ctx) → void
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited