Block class

Implemented types

Constructors

Block({BorderStyle? borderStyle, BorderSides sides = BorderSides.all, String? title, TitleAlign titleAlign = TitleAlign.left, Style? borderColor, Style? titleStyle, Widget? child, Style? fill})
const
Block.bordered({String? title, Widget? child, BorderStyle? style})
factory

Properties

borderColor Style?
final
borderStyle BorderStyle?
final
child Widget?
final
fill Style?
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sides BorderSides
final
title String?
final
titleAlign TitleAlign
final
titleStyle Style?
final

Methods

inner(Rect area) Rect
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
render(Rect area, Buffer buffer, RenderContext ctx) → void
override
titled(String title) Block
toString() String
A string representation of this object.
inherited
withChild(Widget c) Block

Operators

operator ==(Object other) bool
The equality operator.
inherited