BorderSides enum

Inheritance
Available extensions

Values

all → const BorderSides
none → const BorderSides
topBottom → const BorderSides
leftRight → const BorderSides

Properties

hasBottom bool
no setter
hashCode int
The hash code for this object.
no setterinherited
hasLeft bool
no setter
hasRight bool
no setter
hasTop bool
no setter
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<BorderSides>
A constant List of the values in this enum, in order of their declaration.