Buffer class

Available extensions

Constructors

Buffer(Size _size)

Properties

area Rect
no setter
hashCode int
The hash code for this object.
no setterinherited
height int
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size Size
no setter
width int
no setter

Methods

clear([Cell fill = Cell.empty]) → void
fillRect(Rect rect, Cell cell) → void
fillStyle(Rect rect, Style style) → void
get(int x, int y) → Cell
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resize(Size newSize) → void
set(int x, int y, Cell cell) → void
setChar(int x, int y, String char, {Style style = Style.none, int width = 1}) → void
toAnsiString() String

Available on Buffer, provided by the BufferAnsi extension

toPlainString() String
toString() String
A string representation of this object.
inherited
writeText(int x, int y, String text, {Style style = Style.none, int? maxWidth}) → void

Operators

operator ==(Object other) bool
The equality operator.
inherited