Chain class

Implemented types

Constructors

Chain.flow({required ChainFlowState state, required ChainFlowFn flow, void onComplete(List<Object?> values)?, void onError(Object error, StackTrace stack)?, int heightOf(Widget widget)?, int spacing = 0})
const

Properties

flow ChainFlowFn
final
hashCode int
The hash code for this object.
no setterinherited
heightOf int Function(Widget widget)?
final
onComplete → void Function(List<Object?> values)?
final
onError → void Function(Object error, StackTrace stack)?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
spacing int
final
state ChainFlowState
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
render(Rect area, Buffer buffer, RenderContext ctx) → void
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited