ChainFlowContext class

Properties

hashCode int
The hash code for this object.
no setterinherited
history List<Object?>
no setter
index int
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

cancel() → void
complete<T>(T value) → void
draw<T>(Widget widget) Future<T>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited