Checkbox class

Implemented types

Constructors

Checkbox({required Key id, required bool value, String label = '', void onChanged(bool)?, Style? style})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
id Key
final
isSkipped bool
no setteroverride
label String
final
onChanged → void Function(bool)?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
style Style?
final
value bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onKey(KeyEvent event, RenderContext ctx) bool
override
registerHitZones(Rect area, HitZoneSink sink) → void
override
render(Rect area, Buffer buffer, RenderContext ctx) → void
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited