scrollable property

bool scrollable
final

When true the widget becomes focusable and reacts to ↑/↓/PgUp/PgDn/ Home/End to scroll its content vertically. A CodeBlockState is required to persist the scroll offset across frames.

Implementation

final bool scrollable;