CodeTheme class

Constructors

CodeTheme({required Style keyword, required Style string, required Style number, required Style comment, required Style identifier, required Style punctuation, required Style lineNumber, Style background = const Style()})
const

Properties

background Style
final
comment Style
final
hashCode int
The hash code for this object.
no setterinherited
identifier Style
final
keyword Style
final
lineNumber Style
final
number Style
final
punctuation Style
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
string Style
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

defaultFor(RenderContext ctx) CodeTheme