Color24 class final

A 24-bit RGB color.

The values in red, green, and blue are in the range 0-255.

Implemented types

Constructors

Color24(int value)
Creates a Color24 from the lower 24-bits of the provided int value.
const
Color24.fromRGB(int red, int green, int blue)
Creates a Color24 from the provided red, green, and blue values.
const

Properties

blue int
The 8-bit blue component of the color.
no setter
green int
The 8-bit green component of the color.
no setter
hashCode int
The hash code for this object.
no setteroverride
red int
The 8-bit red component of the color.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toRGB() int
Returns the 24-bit RGB value of the color.
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

generate({int sample = 1}) Iterable<Color24>
The 24-bit color palette.