ColorScheme class

Constructors

ColorScheme({Color primary = Color.cyan, Color secondary = Color.magenta, Color background = Color.black, Color foreground = Color.white, Color error = Color.red, Color success = Color.green, Color warning = Color.yellow, Color info = Color.brightBlue, Color muted = Color.brightBlack})
const

Properties

background Color
final
error Color
final
foreground Color
final
hashCode int
The hash code for this object.
no setterinherited
info Color
final
muted Color
final
primary Color
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
secondary Color
final
success Color
final
warning Color
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited