CommanderLogger class abstract interface

Implementers

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

debug(String message, {Object? data}) → void
error(String message, {Object? error, StackTrace? stack}) → void
info(String message, {Object? data}) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
warning(String message, {Object? data}) → void

Operators

operator ==(Object other) bool
The equality operator.
inherited