Constraint class sealed

Implementers

Constructors

Constraint.fill(int weight)
const
factory
Constraint.length(int value)
const
factory
Constraint.max(int value)
const
factory
Constraint.min(int value)
const
factory
Constraint.percentage(int value)
const
factory
Constraint.ratio(int num, int den)
const
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited