Container class

Implemented types

Constructors

Container({BorderStyle? border, String? title, TitleAlign titleAlign = TitleAlign.left, EdgeInsets padding = const EdgeInsets(), Style? fill, Style? borderColor, Widget? child})
const

Properties

border BorderStyle?
final
borderColor Style?
final
child Widget?
final
fill Style?
final
hashCode int
The hash code for this object.
no setterinherited
padding EdgeInsets
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title String?
final
titleAlign TitleAlign
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
render(Rect area, Buffer buffer, RenderContext ctx) → void
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited