DatePicker class

Implemented types

Constructors

DatePicker({Key? id, required DatePickerState state, DateTime? min, DateTime? max, void onSubmit(DateTime value)?, void onChanged(DateTime value)?, List<String> monthNames = const ['January', 'February', 'March', 'April', 'May', 'June', 'July', 'August', 'September', 'October', 'November', 'December'], List<String> weekdayNames = const ['Mo', 'Tu', 'We', 'Th', 'Fr', 'Sa', 'Su'], int firstDayOfWeek = 1, Style? headerStyle, Style? weekdayStyle, Style? dayStyle, Style? selectedStyle, Style? cursorStyle, Style? outsideStyle, Style? disabledStyle})
const

Properties

cursorStyle Style?
final
dayStyle Style?
final
disabledStyle Style?
final
firstDayOfWeek int
final
hashCode int
The hash code for this object.
no setterinherited
headerStyle Style?
final
height int
no setteroverride
id Key
no setteroverride
isSkipped bool
no setteroverride
max DateTime?
final
min DateTime?
final
monthNames List<String>
final
onChanged → void Function(DateTime value)?
final
onSubmit → void Function(DateTime value)?
final
outsideStyle Style?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selectedStyle Style?
final
state DatePickerState
final
weekdayNames List<String>
final
weekdayStyle Style?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onKey(KeyEvent event, RenderContext ctx) bool
override
registerHitZones(Rect area, HitZoneSink sink) → void
override
render(Rect area, Buffer buffer, RenderContext ctx) → void
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited