Dropdown<T> class

Implemented types

Constructors

const

Properties

display String Function(T)?
final
hashCode int
The hash code for this object.
no setterinherited
id Key
no setteroverride
isSkipped bool
no setteroverride
maxDropdownHeight int
final
onChanged → void Function(T value)?
final
options List<T>
final
placeholder String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selected → T?
final
state DropdownState
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onKey(KeyEvent event, RenderContext ctx) bool
override
registerHitZones(Rect area, HitZoneSink sink) → void
override
render(Rect area, Buffer buffer, RenderContext ctx) → void
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited