FlowMode class final

Inheritance

Constructors

FlowMode({int? height, int? minHeight, bool autoGrow = false})
const

Properties

autoGrow bool
final
hashCode int
The hash code for this object.
no setterinherited
height int?
final
minHeight int?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited