FocusableWidget class abstract interface

Implemented types
Implementers

Properties

hashCode int
The hash code for this object.
no setterinherited
id Key
no setter
isSkipped bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onKey(KeyEvent event, RenderContext ctx) bool
registerHitZones(Rect area, HitZoneSink sink) → void
render(Rect area, Buffer buffer, RenderContext ctx) → void
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited