Gauge class

Implemented types

Constructors

Gauge({required num value, num max = 100, String? label, Style? style})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
label → String?
final
max → num
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
style → Style?
final
value → num
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
render(Rect area, Buffer buffer, RenderContext ctx) → void
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited