height property
Number of rows the input needs in its current state.
- 1 row in normal/submitted state.
- 2 rows when displaying an unrecovered validation error.
Implementation
int get height => (!state.submitted && state.error != null) ? 2 : 1;
Number of rows the input needs in its current state.
int get height => (!state.submitted && state.error != null) ? 2 : 1;