InputNumber class

Implemented types

Constructors

InputNumber({Key? id, required InputNumberState state, required String message, String? placeholder, num? min, num? max, num step = 1, bool allowDecimals = false, bool allowNegative = true, num? defaultValue, String? validate(num value)?, void onSubmit(num value)?, void onChanged(num? value)?, bool lockOnSubmit = true, String askPrefix = '?', String errorPrefix = '✗', String successPrefix = '✓', Style? messageStyle, Style? inputStyle, Style? errorStyle, Style? askPrefixStyle, Style? errorPrefixStyle, Style? successPrefixStyle})
const

Properties

allowDecimals bool
final
allowNegative bool
final
askPrefix String
final
askPrefixStyle Style?
final
defaultValue num?
final
errorPrefix String
final
errorPrefixStyle Style?
final
errorStyle Style?
final
hashCode int
The hash code for this object.
no setterinherited
height int
no setteroverride
id Key
no setteroverride
inputStyle Style?
final
isSkipped bool
no setteroverride
lockOnSubmit bool
final
max num?
final
message String
final
messageStyle Style?
final
min num?
final
onChanged → void Function(num? value)?
final
onSubmit → void Function(num value)?
final
placeholder String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
state InputNumberState
final
step num
final
successPrefix String
final
successPrefixStyle Style?
final
validate String? Function(num value)?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onKey(KeyEvent event, RenderContext ctx) bool
override
registerHitZones(Rect area, HitZoneSink sink) → void
override
render(Rect area, Buffer buffer, RenderContext ctx) → void
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited