KeyEvent class

Inheritance

Constructors

KeyEvent({NamedKey? key, String? char, bool ctrl = false, bool alt = false, bool shift = false, List<int> raw = const []})
const

Properties

alt bool
final
char String?
final
ctrl bool
final
hashCode int
The hash code for this object.
no setterinherited
isChar bool
no setter
isNamed bool
no setter
key NamedKey?
final
raw List<int>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shift bool
final

Methods

isChar_(String c) bool
matches(NamedKey named) bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited