Layout class

Constructors

Layout({required Direction direction, required List<Constraint> constraints, int spacing = 0})
const
Layout.horizontal(List<Constraint> constraints, {int spacing = 0})
factory
Layout.vertical(List<Constraint> constraints, {int spacing = 0})
factory

Properties

constraints List<Constraint>
final
direction Direction
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
spacing int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
split(Rect area) List<Rect>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited