LegacyTable class
- Implemented types
Constructors
-
LegacyTable({Key? id, required List<
String> columns, required List<List< rows, required LegacyTableState state, List<String> >int> ? widths}) -
const
Properties
-
columns
→ List<
String> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → Key
-
no setteroverride
- isSkipped → bool
-
no setteroverride
-
rows
→ List<
List< String> > -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- state → LegacyTableState
-
final
-
widths
→ List<
int> ? -
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onKey(
KeyEvent event, RenderContext ctx) → bool -
override
-
registerHitZones(
Rect area, HitZoneSink sink) → void -
override
-
render(
Rect area, Buffer buffer, RenderContext ctx) → void -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited