ListView<T> class

Implemented types

Constructors

ListView({Key? id, required List<T> items, required Widget itemBuilder(T item, bool selected), required ListState state, int itemHeight = 1, void onActivate(T item, int index)?, Style? selectedStyle})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
id Key
no setteroverride
isSkipped bool
no setteroverride
itemBuilder Widget Function(T item, bool selected)
final
itemHeight int
final
items List<T>
final
onActivate → void Function(T item, int index)?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selectedStyle Style?
final
state ListState
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onKey(KeyEvent event, RenderContext ctx) bool
override
registerHitZones(Rect area, HitZoneSink sink) → void
override
render(Rect area, Buffer buffer, RenderContext ctx) → void
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited