NamedKey enum

Inheritance
Available extensions

Values

enter → const NamedKey
escape → const NamedKey
tab → const NamedKey
backspace → const NamedKey
delete → const NamedKey
insert → const NamedKey
arrowUp → const NamedKey
arrowDown → const NamedKey
arrowLeft → const NamedKey
arrowRight → const NamedKey
home → const NamedKey
end → const NamedKey
pageUp → const NamedKey
pageDown → const NamedKey
f1 → const NamedKey
f2 → const NamedKey
f3 → const NamedKey
f4 → const NamedKey
f5 → const NamedKey
f6 → const NamedKey
f7 → const NamedKey
f8 → const NamedKey
f9 → const NamedKey
f10 → const NamedKey
f11 → const NamedKey
f12 → const NamedKey
unknown → const NamedKey

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<NamedKey>
A constant List of the values in this enum, in order of their declaration.