Padding class

Implemented types

Constructors

Padding({required EdgeInsets padding, required Widget child})
const
Padding.all(int v, {required Widget child})
Padding.symmetric({int vertical = 0, int horizontal = 0, required Widget child})

Properties

child Widget
final
hashCode int
The hash code for this object.
no setterinherited
padding EdgeInsets
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
render(Rect area, Buffer buffer, RenderContext ctx) → void
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited