Positioned class

Implemented types

Constructors

Positioned({int? left, int? top, int? width, int? height, required Widget child})
const

Properties

child Widget
final
hashCode int
The hash code for this object.
no setterinherited
height int?
final
left int?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
top int?
final
width int?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
render(Rect area, Buffer buffer, RenderContext ctx) → void
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited