RadioGroup<T> class

Implemented types

Constructors

RadioGroup({required Key id, required List<RadioOption<T>> options, T? selected, void onChanged(T)?})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
id Key
final
isSkipped bool
no setteroverride
onChanged → void Function(T)?
final
options List<RadioOption<T>>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selected → T?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onKey(KeyEvent event, RenderContext ctx) bool
override
registerHitZones(Rect area, HitZoneSink sink) → void
override
render(Rect area, Buffer buffer, RenderContext ctx) → void
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited