RangeState class

Constructors

RangeState({num low = 0, num high = 100, RangeHandle active = RangeHandle.low})

Properties

active RangeHandle
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
high num
getter/setter pair
low num
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited