RenderContext class

Implemented types

Constructors

RenderContext({required Buffer buffer, required Rect area, required ThemeData theme, required FocusController focus, required AsyncRegistry async_, required CommanderLogger logger, required void requestRedraw(), void exit() = _noop})

Properties

area Rect
final
async_ AsyncRegistry
final
buffer Buffer
final
exit → void Function()
final
focus FocusController
final
hashCode int
The hash code for this object.
no setterinherited
hitZones List<({Key key, Rect rect})>
no setter
logger CommanderLogger
final
maxDesiredHeight int
no setter
overlays List<({Rect area, Widget widget})>
no setter
pendingTitle String?
no setter
requestRedraw → void Function()
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
theme ThemeData
final

Methods

add(Rect rect, Key key) → void
override
draw(Widget widget, Rect target) → void
drawOverlay(Widget widget, Rect target) → void
flushOverlays() → void
isFocused(Key id) bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resetFrame() → void
scope(Key id, void drawScope()) → void
setTitle(String title) → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited