RenderMode class sealed

Implementers

Constructors

RenderMode.alternateScreen()
const
factory
RenderMode.flow({int? height, int? minHeight, bool autoGrow})
const
factory
RenderMode.fullScreen()
const
factory
RenderMode.inline({required int height})
const
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited