Screen class
- Implemented types
Constructors
- Screen({required String title, required ScreenBuilder builder, void onExit()?})
-
const
Properties
- builder → ScreenBuilder
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- onExit → void Function()?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- title → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
render(
Rect area, Buffer buffer, RenderContext ctx) → void -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited