ScrollView class

Scrollable container.

Renders child into a virtual buffer of size contentWidth x contentHeight then copies the visible window to the target area, honoring the scroll offsets in state. Receives arrow / PageUp/Down / Home/End keys to scroll.

Implemented types

Constructors

ScrollView({Key? id, required ScrollViewState state, required Widget child, required int contentHeight, int? contentWidth, bool horizontal = false, bool showScrollbar = true, Style? scrollbarStyle, Style? scrollbarThumbStyle})
const

Properties

child Widget
final
contentHeight int
final
contentWidth int
final
hashCode int
The hash code for this object.
no setterinherited
horizontal bool
final
id Key
no setteroverride
isSkipped bool
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scrollbarStyle Style?
final
scrollbarThumbStyle Style?
final
showScrollbar bool
final
state ScrollViewState
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onKey(KeyEvent event, RenderContext ctx) bool
override
registerHitZones(Rect area, HitZoneSink sink) → void
override
render(Rect area, Buffer buffer, RenderContext ctx) → void
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited