ScrollViewState class

Constructors

ScrollViewState({int offsetY = 0, int offsetX = 0, int contentHeight = 0, int contentWidth = 0})

Properties

contentHeight int
getter/setter pair
contentWidth int
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
offsetX int
getter/setter pair
offsetY int
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited