Select<T> class
- Implemented types
Constructors
-
Select({Key? id, required List<
T> items, required SelectState<T> state, required SelectItemBuilder<T> builder, SelectionMode mode = SelectionMode.single, int visibleCount = 5, String placeholder = 'No items', T? defaultValue, List<T> defaultValues = const [], bool filterable = false, SelectFilter<T> ? filter, String filterPlaceholder = 'Filter...', int? minSelections, int? maxSelections, String? validate(List<T> selected)?, void onChanged(T item)?, void onSubmit(List<T> items)?, void onToggle(T item, bool selected)?}) -
const
Properties
-
builder
→ SelectItemBuilder<
T> -
final
- defaultValue → T?
-
final
-
defaultValues
→ List<
T> -
final
-
filter
→ SelectFilter<
T> ? -
final
- filterable → bool
-
final
- filterPlaceholder → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → Key
-
no setteroverride
- isSkipped → bool
-
no setteroverride
-
items
→ List<
T> -
final
- maxSelections → int?
-
final
- minSelections → int?
-
final
- mode → SelectionMode
-
final
- onChanged → void Function(T item)?
-
final
-
onSubmit
→ void Function(List<
T> items)? -
final
- onToggle → void Function(T item, bool selected)?
-
final
- placeholder → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
state
→ SelectState<
T> -
final
-
validate
→ String? Function(List<
T> selected)? -
final
- visibleCount → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onKey(
KeyEvent event, RenderContext ctx) → bool -
override
-
registerHitZones(
Rect area, HitZoneSink sink) → void -
override
-
render(
Rect area, Buffer buffer, RenderContext ctx) → void -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited