SelectItemState class

Constructors

SelectItemState({required bool isActive, required bool isSelected, required bool isFocused, required int index, required bool canSelect})
const

Properties

canSelect bool
final
hashCode int
The hash code for this object.
no setterinherited
index int
final
isActive bool
final
isFocused bool
final
isSelected bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited