SelectState<T> class
Constructors
Properties
- activeIndex ↔ int
-
getter/setter pair
- filterCursor ↔ int
-
getter/setter pair
- filterFocused ↔ bool
-
getter/setter pair
- filterQuery ↔ String
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- initialized ↔ bool
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scrollOffset ↔ int
-
getter/setter pair
-
selected
→ Set<
T> -
final
- validationError ↔ String?
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited