Size class

Constructors

Size(int width, int height)
const
Size.zero()
const

Properties

area int
no setter
hashCode int
The hash code for this object.
no setteroverride
height int
final
isEmpty bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
width int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override