Sparkline class

Single-row line chart using Unicode block characters.

Heights: ▁ ▂ ▃ ▄ ▅ ▆ ▇ █ (8 levels).

Implemented types

Constructors

Sparkline({required List<num> values, num? min, num? max, Style? lineStyle})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
lineStyle Style?
final
max num?
final
min num?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
values List<num>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
render(Rect area, Buffer buffer, RenderContext ctx) → void
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited