Spinner class

Implemented types

Constructors

Spinner({int frame = 0, List<String> frames = const ['⠋', '⠙', '⠹', '⠸', '⠼', '⠴', '⠦', '⠧', '⠇', '⠏'], Style? style, String? label, Key? tickerKey, Duration interval = const Duration(milliseconds: 80)})
const

Properties

frame int
final
frames List<String>
final
hashCode int
The hash code for this object.
no setterinherited
interval Duration
final
label String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
style Style?
final
tickerKey Key?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
render(Rect area, Buffer buffer, RenderContext ctx) → void
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited