StderrLogger class

Implemented types

Constructors

StderrLogger()
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

debug(String message, {Object? data}) → void
override
error(String message, {Object? error, StackTrace? stack}) → void
override
info(String message, {Object? data}) → void
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
warning(String message, {Object? data}) → void
override

Operators

operator ==(Object other) bool
The equality operator.
inherited