Switch class

Implemented types

Constructors

Switch({required Key id, required bool checked, void onChanged(bool value)?, String? label, String onIndicator = '[●━]', String offIndicator = '[━●]', Style? onStyle, Style? offStyle})
const

Properties

checked bool
final
hashCode int
The hash code for this object.
no setterinherited
id Key
final
isSkipped bool
no setteroverride
label String?
final
offIndicator String
final
offStyle Style?
final
onChanged → void Function(bool value)?
final
onIndicator String
final
onStyle Style?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onKey(KeyEvent event, RenderContext ctx) bool
override
registerHitZones(Rect area, HitZoneSink sink) → void
override
render(Rect area, Buffer buffer, RenderContext ctx) → void
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited