Table<T> class

Implemented types

Constructors

Table({Key? id, required List<T> items, required List<TableColumn<T>> columns, required TableState<T> state, bool showHeader = true, Style? headerStyle, Style? headerSeparatorStyle, String headerSeparator = '─', bool selectCells = false, bool selectRows = false, bool selectColumns = false, String? columnSeparator, Style? columnSeparatorStyle, int sortBy(T a, T b)?, bool filter(T item)?, String placeholder = 'No items', bool showScrollIndicators = true, void onRowActivated(int rowIndex, T item)?, void onRowsSelectionChanged(Set<int> rows)?, void onColumnsSelectionChanged(Set<int> columns)?, void onCellsSelectionChanged(Set<CellCoord> cells)?})
const

Properties

columns List<TableColumn<T>>
final
columnSeparator String?
final
columnSeparatorStyle Style?
final
filter bool Function(T item)?
final
hashCode int
The hash code for this object.
no setterinherited
headerSeparator String
final
headerSeparatorStyle Style?
final
headerStyle Style?
final
id Key
no setteroverride
isSkipped bool
no setteroverride
items List<T>
final
onCellsSelectionChanged → void Function(Set<CellCoord> cells)?
final
onColumnsSelectionChanged → void Function(Set<int> columns)?
final
onRowActivated → void Function(int rowIndex, T item)?
final
onRowsSelectionChanged → void Function(Set<int> rows)?
final
placeholder String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selectCells bool
final
selectColumns bool
final
selectRows bool
final
showHeader bool
final
showScrollIndicators bool
final
sortBy int Function(T a, T b)?
final
state TableState<T>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onKey(KeyEvent event, RenderContext ctx) bool
override
registerHitZones(Rect area, HitZoneSink sink) → void
override
render(Rect area, Buffer buffer, RenderContext ctx) → void
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited