TableCellState class

Constructors

TableCellState({required bool isActive, required bool isRowActive, required bool isColumnActive, required bool isCellSelected, required bool isRowSelected, required bool isColumnSelected, required bool isFocused, required int rowIndex, required int columnIndex})
const

Properties

columnIndex int
final
hashCode int
The hash code for this object.
no setterinherited
isActive bool
final
isCellSelected bool
final
isColumnActive bool
final
isColumnSelected bool
final
isFocused bool
final
isRowActive bool
final
isRowSelected bool
final
rowIndex int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited