shutdown abstract method
Full teardown: releases stdin subscriptions, closes event streams, frees native resources. After this, the terminal is unusable — process exit will collect anything left behind.
Implementation
Future<void> shutdown();
Full teardown: releases stdin subscriptions, closes event streams, frees native resources. After this, the terminal is unusable — process exit will collect anything left behind.
Future<void> shutdown();