TextTheme class

Constructors

TextTheme({Style title = const Style(bold: true), Style body = Style.none, Style caption = const Style(dim: true), Style code = Style.none})
const

Properties

body Style
final
caption Style
final
code Style
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title Style
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited