TimePicker class

Implemented types

Constructors

TimePicker({Key? id, required TimePickerState state, bool use24Hour = true, bool showSeconds = false, int hourStep = 1, int minuteStep = 1, int secondStep = 1, void onChanged(int h, int m, int s)?, void onSubmit(int h, int m, int s)?, Style? fieldStyle, Style? activeFieldStyle, Style? separatorStyle})
const

Properties

activeFieldStyle Style?
final
fieldStyle Style?
final
hashCode int
The hash code for this object.
no setterinherited
height int
no setteroverride
hourStep int
final
id Key
no setteroverride
isSkipped bool
no setteroverride
minuteStep int
final
onChanged → void Function(int h, int m, int s)?
final
onSubmit → void Function(int h, int m, int s)?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
secondStep int
final
separatorStyle Style?
final
showSeconds bool
final
state TimePickerState
final
use24Hour bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onKey(KeyEvent event, RenderContext ctx) bool
override
registerHitZones(Rect area, HitZoneSink sink) → void
override
render(Rect area, Buffer buffer, RenderContext ctx) → void
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited