TimePickerState class

Constructors

TimePickerState({int hour = 0, int minute = 0, int second = 0, TimeField active = TimeField.hour, bool submitted = false})

Properties

active TimeField
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
hour int
getter/setter pair
minute int
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
second int
getter/setter pair
submitted bool
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited