TuiNavigator<R> class

Constructors

TuiNavigator({required R initial})

Properties

current → R
no setter
depth int
no setter
hashCode int
The hash code for this object.
no setterinherited
history List<R>
no setter
onChange Stream<void>
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

dispose() Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pop() → R?
push(R route) → void
replace(R route) → void
reset(R route) → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited