AsyncRegistry class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- onCallbackError ↔ void Function(Object error, StackTrace stack)?
-
getter/setter pair
- onResolved ↔ void Function(Key)?
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
beginFrame(
) → void -
disposeAll(
) → void -
endFrame(
) → void -
invalidate(
Key key) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
retry(
Key key) → void -
statusOf(
Key key) → AsyncStatus -
toString(
) → String -
A string representation of this object.
inherited
-
useFuture<
T> (Key key, Future< T> factory()) → AsyncEntry<T> -
useStream<
T> (Key key, Stream< T> factory()) → AsyncEntry<T>
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited