BarChart class
- Implemented types
Constructors
Properties
- barWidth → int
-
final
-
data
→ List<
BarDatum> -
final
- defaultBarStyle → Style?
-
final
- formatValue → String Function(num value)?
-
final
- gap → int
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- labelStyle → Style?
-
final
- max → num?
-
final
- min → num?
-
final
- orientation → BarOrientation
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- showLabels → bool
-
final
- showValues → bool
-
final
- valueStyle → Style?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
render(
Rect area, Buffer buffer, RenderContext ctx) → void -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited