ChainFlowState class
Constructors
Properties
- cancelled ↔ bool
-
getter/setter pair
- completed ↔ bool
-
getter/setter pair
- currentCompleter ↔ Completer?
-
getter/setter pair
- currentWidget ↔ Widget?
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- length → int
-
Number of completed steps so far.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- started ↔ bool
-
getter/setter pair
-
values
→ List<
Object?> -
Collected values from completed steps.
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited