CheckboxGroup<T> class
- Implemented types
Constructors
-
CheckboxGroup({Key? id, required List<
T> items, required CheckboxGroupState<T> state, required CheckboxItemBuilder<T> builder, List<T> defaultChecked = const [], void onChanged(List<T> checked)?}) -
const
Properties
-
builder
→ CheckboxItemBuilder<
T> -
final
-
defaultChecked
→ List<
T> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → Key
-
no setteroverride
- isSkipped → bool
-
no setteroverride
-
items
→ List<
T> -
final
-
onChanged
→ void Function(List<
T> checked)? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
state
→ CheckboxGroupState<
T> -
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onKey(
KeyEvent event, RenderContext ctx) → bool -
override
-
registerHitZones(
Rect area, HitZoneSink sink) → void -
override
-
render(
Rect area, Buffer buffer, RenderContext ctx) → void -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited