scrollable property
When true the widget becomes focusable and reacts to ↑/↓/PgUp/PgDn/ Home/End to scroll its content vertically. A CodeBlockState is required to persist the scroll offset across frames.
Implementation
final bool scrollable;
When true the widget becomes focusable and reacts to ↑/↓/PgUp/PgDn/ Home/End to scroll its content vertically. A CodeBlockState is required to persist the scroll offset across frames.
final bool scrollable;