Color8 class final
An extended color palette that includes the base 16 colors and 240 more.
The 240 colors are a 6x6x6 color cube, with 216 colors, and 24 grayscale colors. The grayscale colors are in the range 0-23, and the color cube is in the range 16-231.
See www.ditig.com/publications/256-colors-cheat-sheet for details.
- Implemented types
Constructors
- Color8.fromIndex(int value)
-
Creates a Color8 with the bottom 8-bits of the provided int value.
const
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override