Constraint class sealed
Constructors
- Constraint.fill(int weight)
-
constfactory
- Constraint.length(int value)
-
constfactory
- Constraint.max(int value)
-
constfactory
- Constraint.min(int value)
-
constfactory
- Constraint.percentage(int value)
-
constfactory
- Constraint.ratio(int num, int den)
-
constfactory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited