Divider class
- Implemented types
Constructors
- Divider({DividerOrientation orientation = DividerOrientation.horizontal, String char = '─', Style? style})
-
const
- Divider.vertical({String char = '│', Style? style})
-
factory
Properties
- char → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- orientation → DividerOrientation
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- style → Style?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
render(
Rect area, Buffer buffer, RenderContext ctx) → void -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited