Each<T> class
- Implemented types
Constructors
Properties
- builder → Widget Function(T item, int index)
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- heightOf → int Function(T item, int index)?
-
final
-
items
→ Iterable<
T> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- spacing → int
-
final
- where → bool Function(T item, int index)?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
render(
Rect area, Buffer buffer, RenderContext ctx) → void -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited