FocusController class
Constructors
Properties
- current → Key?
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scopeDepth → int
-
no setter
Methods
-
clear(
) → void -
contains(
Key id) → bool -
dispatchKey(
KeyEvent event) → bool -
finalizeFrame(
) → void -
focus(
Key id) → void -
isFocused(
Key id) → bool -
next(
) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
popScope(
) → void -
previous(
) → void -
pushScope(
Key id) → void -
register(
Key id, {bool skip = false, KeyHandler? handler}) → void -
resetFrame(
) → void -
scopeId(
) → Key? -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited