Input class
- Implemented types
Constructors
- Input({Key? id, required String message, required InputState state, String? defaultValue, String? placeholder, bool obscure = false, String? validate(String value)?, void onSubmit(String value)?, void onChanged(String value)?, bool lockOnSubmit = true, String askPrefix = '?', String errorPrefix = '✗', String successPrefix = '✓', Style? messageStyle, Style? inputStyle, Style? defaultValueStyle, Style? errorStyle, Style? askPrefixStyle, Style? errorPrefixStyle, Style? successPrefixStyle})
-
const
Properties
- askPrefix → String
-
final
- askPrefixStyle → Style?
-
final
- defaultValue → String?
-
final
- defaultValueStyle → Style?
-
final
- errorPrefix → String
-
final
- errorPrefixStyle → Style?
-
final
- errorStyle → Style?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- height → int
-
Number of rows the input needs in its current state.
no setteroverride
- id → Key
-
no setteroverride
- inputStyle → Style?
-
final
- isSkipped → bool
-
no setteroverride
- lockOnSubmit → bool
-
final
- message → String
-
final
- messageStyle → Style?
-
final
- obscure → bool
-
final
- onChanged → void Function(String value)?
-
final
- onSubmit → void Function(String value)?
-
final
- placeholder → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- state → InputState
-
final
- successPrefix → String
-
final
- successPrefixStyle → Style?
-
final
- validate → String? Function(String value)?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onKey(
KeyEvent event, RenderContext ctx) → bool -
override
-
registerHitZones(
Rect area, HitZoneSink sink) → void -
override
-
render(
Rect area, Buffer buffer, RenderContext ctx) → void -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited