Rect class
Properties
- area → int
-
no setter
- bottom → int
-
no setter
- hashCode → int
-
The hash code for this object.
no setteroverride
- height → int
-
final
- isEmpty → bool
-
no setter
- left → int
-
no setter
- right → int
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- top → int
-
no setter
- width → int
-
final
- x → int
-
final
- y → int
-
final
Methods
-
contains(
int px, int py) → bool -
inset(
{int top = 0, int right = 0, int bottom = 0, int left = 0}) → Rect -
insetAll(
int v) → Rect -
intersect(
Rect other) → Rect -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override