Slider class
- Implemented types
Constructors
- Slider({Key? id, required SliderState state, num min = 0, num max = 100, num step = 1, num? pageStep, void onChanged(num value)?, String trackChar = '─', String fillChar = '━', String handleChar = '●', Style? trackStyle, Style? fillStyle, Style? handleStyle, bool showValue = true, String formatValue(num value)?})
-
const
Properties
- fillChar → String
-
final
- fillStyle → Style?
-
final
- formatValue → String Function(num value)?
-
final
- handleChar → String
-
final
- handleStyle → Style?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- height → int
-
no setteroverride
- id → Key
-
no setteroverride
- isSkipped → bool
-
no setteroverride
- max → num
-
final
- min → num
-
final
- onChanged → void Function(num value)?
-
final
- pageStep → num?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- showValue → bool
-
final
- state → SliderState
-
final
- step → num
-
final
- trackChar → String
-
final
- trackStyle → Style?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onKey(
KeyEvent event, RenderContext ctx) → bool -
override
-
registerHitZones(
Rect area, HitZoneSink sink) → void -
override
-
render(
Rect area, Buffer buffer, RenderContext ctx) → void -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited