Style class
Constructors
Properties
- bg → Color?
-
final
- bold → bool
-
final
- dim → bool
-
final
- fg → Color?
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- italic → bool
-
final
- reverse → bool
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- strikethrough → bool
-
final
- underline → bool
-
final
Methods
-
copyWith(
{Color? fg, Color? bg, bool? bold, bool? italic, bool? underline, bool? dim, bool? reverse, bool? strikethrough}) → Style -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
over(
Style? other) → Style -
Paint
thison top ofother—thiswins where it sets a value. Mnemonic:top.over(bottom). -
toString(
) → String -
A string representation of this object.
inherited
-
under(
Style? other) → Style -
Paint
thisunderneathother—otherwins where it sets a value. Mnemonic:bottom.under(top). Equivalent toother.over(this). -
withBg(
Color c) → Style -
withFg(
Color c) → Style
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
bolded(
) → Style -
dimmed(
) → Style -
italicized(
) → Style -
underlined(
) → Style