TableColumn<T> class
Constructors
-
TableColumn({required String title, required TableCellBuilder<
T> cellBuilder, TableConstraint width = const TableConstraint.fill(1), Style? headerStyle, TextAlign headerAlign = TextAlign.left}) -
const
Properties
-
cellBuilder
→ TableCellBuilder<
T> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- headerAlign → TextAlign
-
final
- headerStyle → Style?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- title → String
-
final
- width → TableConstraint
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited