TableState<T> class
Constructors
Properties
- activeColumn ↔ int
-
getter/setter pair
- activeRow ↔ int
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- horizontalScroll ↔ int
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
selectedCells
→ Set<
CellCoord> -
final
-
selectedColumns
→ Set<
int> -
final
-
selectedRows
→ Set<
int> -
final
- verticalScroll ↔ int
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited