Tabs class
- Implemented types
Constructors
Properties
- activeStyle → Style?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → Key
-
final
- inactiveStyle → Style?
-
final
- isSkipped → bool
-
no setteroverride
- onTabSelected → void Function(int index)?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- selected → int
-
final
-
tabs
→ List<
String> -
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onKey(
KeyEvent event, RenderContext ctx) → bool -
override
-
registerHitZones(
Rect area, HitZoneSink sink) → void -
override
-
render(
Rect area, Buffer buffer, RenderContext ctx) → void -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited