TextArea class
- Implemented types
Constructors
Properties
- cursorStyle → Style?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → Key
-
no setteroverride
- isSkipped → bool
-
no setteroverride
- maxLength → int?
-
final
- maxLines → int?
-
final
- onChanged → void Function(String value)?
-
final
- onSubmit → void Function(String value)?
-
final
- placeholder → String?
-
final
- placeholderStyle → Style?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- state → TextAreaState
-
final
- submitOnCtrlEnter → bool
-
final
- textStyle → Style?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onKey(
KeyEvent event, RenderContext ctx) → bool -
override
-
registerHitZones(
Rect area, HitZoneSink sink) → void -
override
-
render(
Rect area, Buffer buffer, RenderContext ctx) → void -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited