TextField class
- Implemented types
Constructors
-
TextField({required Key id, required String value, String placeholder = '', ValueChanged<
String> ? onChanged, VoidCallback? onSubmit, bool obscure = false, bool validate(String)?, Style? focusedStyle, Style? unfocusedStyle, BorderStyle? border, TextFieldState? state}) -
const
Properties
- border → BorderStyle?
-
final
- focusedStyle → Style?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → Key
-
final
- isSkipped → bool
-
no setteroverride
- obscure → bool
-
final
-
onChanged
→ ValueChanged<
String> ? -
final
- onSubmit → VoidCallback?
-
final
- placeholder → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- state → TextFieldState?
-
final
- unfocusedStyle → Style?
-
final
- validate → bool Function(String)?
-
final
- value → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onKey(
KeyEvent event, RenderContext ctx) → bool -
override
-
registerHitZones(
Rect area, HitZoneSink sink) → void -
override
-
render(
Rect area, Buffer buffer, RenderContext ctx) → void -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited