ThemeData class
Constructors
- ThemeData({ColorScheme colors = const ColorScheme(), BorderTheme borders = const BorderTheme(), TextTheme text = const TextTheme()})
-
const
Properties
- borders → BorderTheme
-
final
- colors → ColorScheme
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- text → TextTheme
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited