Tree<T> class
- Implemented types
Constructors
-
Tree({Key? id, required List<
TreeNode< roots, required TreeState<T> >T> state, required Object keyOf(TreeNode<T> node, List<int> path), void onActivate(TreeNode<T> node)?, void onExpansionChanged(TreeNode<T> node, bool expanded)?, String expandedIcon = '▼', String collapsedIcon = '▶', String leafIcon = '·', int indent = 2, Style? itemStyle, Style? activeStyle, Style? iconStyle}) -
const
Properties
- activeStyle → Style?
-
final
- collapsedIcon → String
-
final
- expandedIcon → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- iconStyle → Style?
-
final
- id → Key
-
no setteroverride
- indent → int
-
final
- isSkipped → bool
-
no setteroverride
- itemStyle → Style?
-
final
-
keyOf
→ Object Function(TreeNode<
T> node, List<int> path) -
final
- leafIcon → String
-
final
-
onActivate
→ void Function(TreeNode<
T> node)? -
final
-
onExpansionChanged
→ void Function(TreeNode<
T> node, bool expanded)? -
final
-
roots
→ List<
TreeNode< T> > -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
state
→ TreeState<
T> -
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onKey(
KeyEvent event, RenderContext ctx) → bool -
override
-
registerHitZones(
Rect area, HitZoneSink sink) → void -
override
-
render(
Rect area, Buffer buffer, RenderContext ctx) → void -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited